type Options = {
    count?: number;
    defaultLimited?: boolean;
};
/**
 * 管理列表展示数量的 Hook。
 *
 * @param {Array} list 列表数据。
 * @param {Object} [options] 配置项。
 * @param {number} [options.count=3] 默认限制列表数量。默认 `3`。
 * @param {boolean} [options.defaultLimited=true] 默认是否限制列表数据。默认 `true`。
 * @returns
 * @example
 * const { data, limited, canLimit, toggle } = useLimitList(list);
 */
declare function useLimitList<T>(list?: T[], options?: Options): {
    /**
     * 是否可以限制列表数量。当列表数量小于等于 `count` 时，为 `false`。
     */
    canLimit: boolean;
    /**
     * 当前是否限制列表数据。
     */
    limited: boolean;
    /**
     * 列表数据。
     */
    data: T[];
    /**
     * 切换限制列表数据。
     */
    toggle: () => void;
};
export default useLimitList;
