"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var react_1 = require("react");
var useThrottleFn_1 = tslib_1.__importDefault(require("../useThrottleFn"));
/**
 * 用来处理节流值的 Hook。
 *
 * @param {*} value 需要节流的值。
 * @param {number} [wait=0] 节流等待时间，单位为毫秒。默认 `0`。
 * @param {boolean} [immediate=true] 是否在延迟开始前调用。默认 `true`。
 * @returns
 * @example
 * const [value, setValue] = useState('');
 * // 频繁调用 setValue ， throttledValue 每隔 500ms 变化一次。
 * const throttledValue = useThrottle(value, 500);
 */
function useThrottle(value, wait, immediate) {
    if (wait === void 0) { wait = 0; }
    if (immediate === void 0) { immediate = true; }
    var _a = tslib_1.__read((0, react_1.useState)(value), 2), state = _a[0], setState = _a[1];
    var run = (0, useThrottleFn_1.default)(setState, wait, immediate).run;
    (0, react_1.useEffect)(function () {
        run(value);
    }, [run, value]);
    return state;
}
exports.default = useThrottle;
